package com.ruoyi.ems.record.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ems.record.mapper.EmsRecordSteamInstantMapper;
import com.ruoyi.ems.record.domain.EmsRecordSteamInstant;
import com.ruoyi.ems.record.service.IEmsRecordSteamInstantService;

/**
 * 蒸汽实时数据Service业务层处理
 *
 * @author Yinq
 * @date 2024-05-22
 */
@Service
public class EmsRecordSteamInstantServiceImpl implements IEmsRecordSteamInstantService {
    @Autowired
    private EmsRecordSteamInstantMapper emsRecordSteamInstantMapper;

    /**
     * 查询蒸汽实时数据
     *
     * @param objId 蒸汽实时数据主键
     * @return 蒸汽实时数据
     */
    @Override
    public EmsRecordSteamInstant selectEmsRecordSteamInstantByObjId(Long objId) {
        return emsRecordSteamInstantMapper.selectEmsRecordSteamInstantByObjId(objId);
    }

    /**
     * 查询蒸汽实时数据列表
     *
     * @param emsRecordSteamInstant 蒸汽实时数据
     * @return 蒸汽实时数据
     */
    @Override
    public List<EmsRecordSteamInstant> selectEmsRecordSteamInstantList(EmsRecordSteamInstant emsRecordSteamInstant) {
        return emsRecordSteamInstantMapper.selectEmsRecordSteamInstantList(emsRecordSteamInstant);
    }

    /**
     * 新增蒸汽实时数据
     *
     * @param emsRecordSteamInstant 蒸汽实时数据
     * @return 结果
     */
    @Override
    public int insertEmsRecordSteamInstant(EmsRecordSteamInstant emsRecordSteamInstant) {
        return emsRecordSteamInstantMapper.insertEmsRecordSteamInstant(emsRecordSteamInstant);
    }

    /**
     * 修改蒸汽实时数据
     *
     * @param emsRecordSteamInstant 蒸汽实时数据
     * @return 结果
     */
    @Override
    public int updateEmsRecordSteamInstant(EmsRecordSteamInstant emsRecordSteamInstant) {
        return emsRecordSteamInstantMapper.updateEmsRecordSteamInstant(emsRecordSteamInstant);
    }

    /**
     * 批量删除蒸汽实时数据
     *
     * @param objIds 需要删除的蒸汽实时数据主键
     * @return 结果
     */
    @Override
    public int deleteEmsRecordSteamInstantByObjIds(Long[] objIds) {
        return emsRecordSteamInstantMapper.deleteEmsRecordSteamInstantByObjIds(objIds);
    }

    /**
     * 删除蒸汽实时数据信息
     *
     * @param objId 蒸汽实时数据主键
     * @return 结果
     */
    @Override
    public int deleteEmsRecordSteamInstantByObjId(Long objId) {
        return emsRecordSteamInstantMapper.deleteEmsRecordSteamInstantByObjId(objId);
    }
}
