package com.ruoyi.ems.record.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ems.record.domain.EmsRecordSteamInstant;
import com.ruoyi.ems.record.service.IEmsRecordSteamInstantService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 蒸汽实时数据Controller
 *
 * @author Yinq
 * @date 2024-05-22
 */
@RestController
@RequestMapping("/ems/record/recordSteamInstant")
public class EmsRecordSteamInstantController extends BaseController {
    @Autowired
    private IEmsRecordSteamInstantService emsRecordSteamInstantService;

    /**
     * 查询蒸汽实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordSteamInstant:list')")
    @GetMapping("/list")
    public TableDataInfo list(EmsRecordSteamInstant emsRecordSteamInstant) {
        startPage();
        List<EmsRecordSteamInstant> list = emsRecordSteamInstantService.selectEmsRecordSteamInstantList(emsRecordSteamInstant);
        return getDataTable(list);
    }

    /**
     * 导出蒸汽实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordSteamInstant:export')")
    @Log(title = "蒸汽实时数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EmsRecordSteamInstant emsRecordSteamInstant) {
        List<EmsRecordSteamInstant> list = emsRecordSteamInstantService.selectEmsRecordSteamInstantList(emsRecordSteamInstant);
        ExcelUtil<EmsRecordSteamInstant> util = new ExcelUtil<EmsRecordSteamInstant>(EmsRecordSteamInstant.class);
        util.exportExcel(response, list, "蒸汽实时数据数据");
    }

    /**
     * 获取蒸汽实时数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordSteamInstant:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(emsRecordSteamInstantService.selectEmsRecordSteamInstantByObjId(objId));
    }

    /**
     * 新增蒸汽实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordSteamInstant:add')")
    @Log(title = "蒸汽实时数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmsRecordSteamInstant emsRecordSteamInstant) {
        emsRecordSteamInstant.setCreateBy(getUsername());
        return toAjax(emsRecordSteamInstantService.insertEmsRecordSteamInstant(emsRecordSteamInstant));
    }

    /**
     * 修改蒸汽实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordSteamInstant:edit')")
    @Log(title = "蒸汽实时数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmsRecordSteamInstant emsRecordSteamInstant) {
        emsRecordSteamInstant.setUpdateBy(getUsername());
        return toAjax(emsRecordSteamInstantService.updateEmsRecordSteamInstant(emsRecordSteamInstant));
    }

    /**
     * 删除蒸汽实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordSteamInstant:remove')")
    @Log(title = "蒸汽实时数据", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(emsRecordSteamInstantService.deleteEmsRecordSteamInstantByObjIds(objIds));
    }
}
